@@ -5,6 +5,7 @@
 
 
 import os, sys, argparse, re, json
+import cupkb
 
 from matplotlib.pylab import *
 import torch.nn as nn
@@ -770,8 +771,8 @@ def print_result(epoch, acc, dname):
     )
 
 
-if __name__ == '__main__':
-
+#if __name__ == '__main__':
+def start():
     ## 1. Hyper parameters 读取参数
     parser = argparse.ArgumentParser()
     args = construct_hyper_param(parser)
